#biomechanical correlations
#assumes that I have loaded variables "tree.list", "all.data"
tree <- tree.list[[2]];
all.data <- all.data[tree$tip.label,];#makes life easier later

#produce size-corrected variables using Revell 2009 size-correction (alternative way of doing it, as compared to next set of code below)
all.data.alt<-all.data;
dummy<-phyl.resid(tree,all.data[,3],all.data[,11:12],method="BM");
all.data.alt$rel.toepad<-apply(dummy$resid,1,sum);
rm(dummy);
all.data.alt$rel.leg<-phyl.resid(tree,all.data[,3],all.data[,4],method="BM")$resid;
all.data.alt$rel.cling<-phyl.resid(tree,all.data[,3],all.data[,20],method="BM")$resid;

#get weird results for above, so just do normal size-correction (though weirdness seems to relate to transformation)
all.data$rel.toepad<-apply(all.data[,11:12],1,sum)/all.data[,3];
all.data$rel.leg<-all.data[,4]/all.data[,3]
all.data$rel.cling<-all.data[,20]/all.data[,3]


#first take subsets of variables
#arboreal taxa
arboreal.data<-all.data[all.data$microhab=="arboreal",];
arboreal.phylo<-all.data.phylo[all.data.phylo$microhab=="arboreal",];
arboreal.data.alt<-all.data.alt[all.data.alt$microhab=="arboreal",]

########################################################################################################################3
#now correlations, non-phylogenetic
#relative toepad size and clinging angle
#all.data$rel.toepad<-(all.data$FtPad+all.data$HdPad)/all.data$SVL;
pad.angle.lm<-lm(MaxCling~SVL+rel.toepad,data=all.data);
summary(pad.angle.lm);
plot(pad.angle.lm);
plot(all.data$rel.toepad,all.data$rel.cling)
abline(pad.angle.lm);

#relative toepad size and clinging angle in arboreal taxa
#arboreal.data$rel.toepad<-(arboreal.data$FtPad+arboreal.data$HdPad)/arboreal.data$SVL;
pad.angle.arb.lm<-lm(MaxCling~SVL+rel.toepad,data=arboreal.data);
summary(pad.angle.arb.lm);
plot(pad.angle.arb.lm);

#relative muscle size and various performance variables
swim.acc.lm<-lm(SwimMaxAcc~SVL+RelLegMass,data=all.data);
summary(swim.acc.lm);
swim.power.lm<-lm(SwimMaxPow~SVL+RelLegMass,data=all.data);
summary(swim.power.lm);
jump.acc.lm<-lm(JumpMaxAcc~SVL+RelLegMass,data=all.data);
summary(jump.acc.lm);
jump.power.lm<-lm(JumpMaxPower~SVL+RelLegMass,data=all.data);
summary(jump.power.lm);

#relative leg length, muscle size, and jumping velocity
jump.vel.lm<-lm(JumpMaxVel~SVL+RelLegMass+rel.leg,data=all.data);
summary(jump.vel.lm);

#relative leg length and jumping velocity
jump.vel2.lm<-lm(JumpMaxVel~SVL+rel.leg,data=all.data);
summary(jump.vel2.lm);

#################################################################################################################################
#Now GLS models computed directly, on Revell-2009-adjusted data
pad.angle.pgls<-gls(MaxCling~SVL+rel.toepad,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(pad.angle.pgls);
par(mfcol=c(1,2));
plot(all.data.alt$rel.toepad,all.data.alt$MaxCling);
plot(all.data.alt$SVL,all.data.alt$MaxCling);
plot(all.data.alt$rel.toepad,all.data.alt$rel.cling);


#relative toepad size and clinging angle in arboreal taxa
arboreal.tree<-drop.tip(tree,rownames(all.data.alt[all.data.alt$microhab!="arboreal",]));
plot(arboreal.tree);
name.check(arboreal.tree,arboreal.data.alt);
pad.angle.arboreal.pgls<-gls(MaxCling~SVL+rel.toepad,data=arboreal.data.alt,correlation=corBrownian(1,phy=arboreal.tree));
summary(pad.angle.arboreal.pgls);
plot(arboreal.data.alt$rel.toepad,arboreal.data.alt$MaxCling);
plot(arboreal.data.alt$SVL,arboreal.data.alt$MaxCling);
plot(arboreal.data.alt$rel.toepad,arboreal.data.alt$rel.cling);

#relative muscle size and various performance variables
swim.acc.pgls<-gls(SwimMaxAcc~SVL+RelLegMass,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(swim.acc.pgls);
swim.power.pgls<-gls(SwimMaxPow~SVL+RelLegMass,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(swim.power.pgls);
jump.acc.pgls<-gls(JumpMaxAcc~SVL+RelLegMass,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(jump.acc.pgls);
jump.power.pgls<-gls(JumpMaxPower~SVL+RelLegMass,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(jump.power.pgls);

#relative leg length, muscle size, and jumping velocity
jump.vel.pgls<-gls(JumpMaxVel~SVL+RelLegMass+rel.leg,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(jump.vel.pgls);
#correlation between relative leg length and relative muscle mass
leg.muscle.pgls<-gls(RelLegMass~rel.leg,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(leg.muscle.pgls);
plot(all.data.alt$rel.leg,all.data.alt$RelLegMass)
#alternative, given that the above is regression, not correlation
leg.mass.IC<-pic(all.data.alt$RelLegMass,tree)
leg.length.IC<-pic(all.data.alt$rel.leg,tree)
cor.test(leg.length.IC,leg.mass.IC);
plot(leg.length.IC,leg.mass.IC);

#relative leg length and jumping velocity
jump.vel2.pgls<-gls(JumpMaxVel~SVL+rel.leg,data=all.data.alt,correlation=corBrownian(1,phy=tree));
summary(jump.vel2.pgls);








